#!/usr/bin/env python

#PBS -N au147c 
#PBS -e au147c.err
#PBS -o au147c.log
#PBS -m ae
#PBS -q small
#PBS -l nodes=1:ppn=8:xeon5570

from ase import *
from ase.utils.eos import *
from gpaw import *
from gpaw.poisson import PoissonSolver


box = 22.0
#### Build an 147-atom Au cuboctahedron.
cubocta = read('Au147c.xyz')
cubocta.set_cell([box, box, box])
cubocta.center()
write('au147c.original.traj', cubocta)

solver = PoissonSolver(relax='GS', eps=1e-8)

root = 'au147c'
calc = GPAW(gpts=(128, 128, 128),
            poissonsolver=solver,
            mode='lcao',
            basis='dzp',
            nbands = 850,
            xc     = 'PBE',
            width  = 0.01,
            txt='%s.gpaw.out' % root)
cubocta.set_calculator(calc)

#### Single point energy ####
e0 = cubocta.get_potential_energy()
#calc.write('au147c.original.gpw')
