#!/usr/bin/env python

#PBS -N au147c 
#PBS -e au147c.err
#PBS -o au147c.log
#PBS -m ae
#PBS -q verylong
#PBS -l nodes=8:ppn=4

from ase import *
from ase.utils.eos import *
from gpaw import * 

box = 22.0
#### Build an 147-atom Au cuboctahedron.
cubocta = read('Au147c.xyz')
cubocta.set_cell([box, box, box])
cubocta.center()
write('au147c.original.traj', cubocta)

root = 'au147c'
calc = GPAW(h      = 0.18,
            basis  = 'dzp',
            mode   = 'lcao',
            nbands = 850,
            xc     = 'PBE',
            width  = 0.01,
            mixer  = Mixer(0.1, 5, metric='new', weight=100.0),
            txt=root+'.gpaw.out')
cubocta.set_calculator(calc)

#### Single point energy ####
e0 = cubocta.get_total_energy()
d0 = cubocta.get_distance(0, 1)
calc.write('au147c.original.gpw')

#### Relaxation          ####
relax = QuasiNewton(cubocta, logfile='qn.log')
relax.run(fmax=0.05)
e1  = cubocta.get_total_energy()
d01 = cubocta.get_distance(62, 61)
d02 = cubocta.get_distance(62, 60)
d03 = cubocta.get_distance(62, 63)
write('au147c.relaxed.traj', cubocta)
calc.write('au147c.relaxed.gpw')

#### Output to the out.txt file.
file = open('./out.txt','w')
s0   = 'Single point energy calculation:\n'
s1   = 'Total energy is '+str(e0)+' eV.\n'
s2   = 'Distance between center and vertex is ' +str(d0)+' A.\n\n'
s3   = 'Relaxation:\n'
s4   = 'Total energy is '+str(e1)+' eV.\n'
s5   = 'Distance between center and first shell is ' +str(d01)+' A.\n'

file.write(s0+s1+s2+s3+s4+s5)
file.close()
#### Output ended.
